@@ -29,7 +29,7 @@ def convert_to_xls(reqmodule, file):
 
 
 def convert_to_markdown(reqmodule, file, hugo=False):
-    md_file = open(file)
+    md_file = open(file, 'w')
     if hugo:
         md_file.write('---\n'
                       'title: ' + os.path.basename(reqmodule.module_path) + '\n' 
@@ -212,6 +212,7 @@ def draw_coverage_diagrams(reqmodule, dont_show_output=False):
 
         # ending angle values
     end_angle = start_angle[1:] + [math.radians(0)]
+    end_angle[-1] = math.radians(360)
 
     # center of the pie chart
     x = 0
